@@ -121,6 +121,7 @@ final class AwsProtocolUtils {
                         .addTestName("AwsJson10ClientPopulatesDefaultValuesInInput")
                         .addTestName("AwsJson10ClientSkipsTopLevelDefaultValuesInInput")
                         .addTestName("AwsJson10ClientUsesExplicitlyProvidedMemberValuesOverDefaults")
+                        .addTestName("AwsJson10ClientUsesExplicitlyProvidedValuesInTopLevel")
                         .build(),
                 HttpProtocolUnitTestGenerator.SkipTest.builder()
                         .service(ShapeId.from("aws.protocoltests.json10#JsonRpc10"))
@@ -196,30 +197,6 @@ final class AwsProtocolUtils {
         ).generateProtocolTests();
     }
 
-    public static void writeJsonErrorMessageCodeDeserializer(GenerationContext context) {
-        GoWriter writer = context.getWriter().get();
-        // The error code could be in the headers, even though for this protocol it should be in the body.
-        writer.write("headerCode := response.Header.Get(\"X-Amzn-ErrorType\")");
-        writer.write("if len(headerCode) != 0 { errorCode = restjson.SanitizeErrorCode(headerCode) }");
-        writer.write("");
-
-        initializeJsonDecoder(writer, "errorBody");
-        writer.addUseImports(AwsGoDependency.AWS_REST_JSON_PROTOCOL);
-        // This will check various body locations for the error code and error message
-        writer.write("jsonCode, message, err := restjson.GetErrorInfo(decoder)");
-        handleDecodeError(writer);
-
-        writer.addUseImports(SmithyGoDependency.IO);
-        // Reset the body in case it needs to be used for anything else.
-        writer.write("errorBody.Seek(0, io.SeekStart)");
-
-        // Only set the values if something was found so that we keep the default values.
-        // The header version of the error wins out over either of the body fields.
-        writer.write("if len(headerCode) == 0 && len(jsonCode) != 0 { errorCode = restjson.SanitizeErrorCode(jsonCode) }");
-        writer.write("if len(message) != 0 { errorMessage = message }");
-        writer.write("");
-    }
-
     public static void initializeJsonDecoder(GoWriter writer, String bodyLocation) {
         // Use a ring buffer and tee reader to help in pinpointing any deserialization errors.
         writer.addUseImports(SmithyGoDependency.SMITHY_IO);
